cancelMessage property
The text message to display when the user cancels a chat operation.
Defaults to 'CANCEL'.
Implementation
final String cancelMessage;
The text message to display when the user cancels a chat operation.
Defaults to 'CANCEL'.
final String cancelMessage;