LlmChatViewStyle class
Style for the entire chat widget.
- Annotations
Constructors
- LlmChatViewStyle({Color? backgroundColor, Color? progressIndicatorColor, UserMessageStyle? userMessageStyle, LlmMessageStyle? llmMessageStyle, ChatInputStyle? chatInputStyle, ActionButtonStyle? addButtonStyle, ActionButtonStyle? attachFileButtonStyle, ActionButtonStyle? cameraButtonStyle, ActionButtonStyle? stopButtonStyle, ActionButtonStyle? closeButtonStyle, ActionButtonStyle? cancelButtonStyle, ActionButtonStyle? copyButtonStyle, ActionButtonStyle? editButtonStyle, ActionButtonStyle? galleryButtonStyle, ActionButtonStyle? recordButtonStyle, ActionButtonStyle? submitButtonStyle, ActionButtonStyle? disabledButtonStyle, ActionButtonStyle? closeMenuButtonStyle, Decoration? actionButtonBarDecoration, FileAttachmentStyle? fileAttachmentStyle, SuggestionStyle? suggestionStyle, VoiceNoteRecorderStyle? voiceNoteRecorderStyle, ActionButtonStyle? urlButtonStyle, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, double? messageSpacing})
-
Creates a style object for the chat widget.
const
- LlmChatViewStyle.defaultStyle()
-
Provides default style if none is specified.
factory
- LlmChatViewStyle.resolve(LlmChatViewStyle? style, {LlmChatViewStyle? defaultStyle})
-
Resolves the provided
stylewith thedefaultStyle.factory
Properties
- actionButtonBarDecoration → Decoration?
-
Decoration for the action button bar.
final
- addButtonStyle → ActionButtonStyle?
-
Style for the add button.
final
- attachFileButtonStyle → ActionButtonStyle?
-
Style for the attach file button.
final
- backgroundColor → Color?
-
Background color of the entire chat widget.
final
- cameraButtonStyle → ActionButtonStyle?
-
Style for the camera button.
final
- cancelButtonStyle → ActionButtonStyle?
-
Style for the cancel button.
final
- chatInputStyle → ChatInputStyle?
-
Style for the input text box.
final
- closeButtonStyle → ActionButtonStyle?
-
Style for the close button.
final
- closeMenuButtonStyle → ActionButtonStyle?
-
Style for the close menu button.
final
- copyButtonStyle → ActionButtonStyle?
-
Style for the copy button.
final
- disabledButtonStyle → ActionButtonStyle?
-
Style for the disabled button.
final
- editButtonStyle → ActionButtonStyle?
-
Style for the edit button.
final
- fileAttachmentStyle → FileAttachmentStyle?
-
Style for file attachments.
final
- galleryButtonStyle → ActionButtonStyle?
-
Style for the gallery button.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- llmMessageStyle → LlmMessageStyle?
-
Style for LLM messages.
final
- margin → EdgeInsetsGeometry?
-
Margin around the entire chat view.
final
-
The color of the menu.
final
- messageSpacing → double?
-
Spacing between messages.
final
- padding → EdgeInsetsGeometry?
-
Default padding around the chat view.
final
- progressIndicatorColor → Color?
-
The color of the progress indicator.
final
- recordButtonStyle → ActionButtonStyle?
-
Style for the record button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopButtonStyle → ActionButtonStyle?
-
Style for the stop button.
final
- submitButtonStyle → ActionButtonStyle?
-
Style for the submit button.
final
- suggestionStyle → SuggestionStyle?
-
Style for suggestions.
final
- urlButtonStyle → ActionButtonStyle?
-
Style for the URL button.
final
- userMessageStyle → UserMessageStyle?
-
Style for user messages.
final
- voiceNoteRecorderStyle → VoiceNoteRecorderStyle?
-
Style for the waveform recorder.
final
Methods
-
copyWith(
{Color? backgroundColor, Color? progressIndicatorColor, UserMessageStyle? userMessageStyle, LlmMessageStyle? llmMessageStyle, ChatInputStyle? chatInputStyle, ActionButtonStyle? addButtonStyle, ActionButtonStyle? attachFileButtonStyle, ActionButtonStyle? cameraButtonStyle, ActionButtonStyle? stopButtonStyle, ActionButtonStyle? closeButtonStyle, ActionButtonStyle? cancelButtonStyle, ActionButtonStyle? copyButtonStyle, ActionButtonStyle? editButtonStyle, ActionButtonStyle? galleryButtonStyle, ActionButtonStyle? recordButtonStyle, ActionButtonStyle? submitButtonStyle, ActionButtonStyle? disabledButtonStyle, ActionButtonStyle? closeMenuButtonStyle, Decoration? actionButtonBarDecoration, FileAttachmentStyle? fileAttachmentStyle, SuggestionStyle? suggestionStyle, VoiceNoteRecorderStyle? voiceNoteRecorderStyle, ActionButtonStyle? urlButtonStyle, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, double? messageSpacing}) → LlmChatViewStyle - Creates a copy of this style with the given fields replaced by the new
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited