LlmProvider class abstract
An abstract class representing a Language Model (LLM) provider.
This class defines the interface for interacting with different LLM services. Implementations of this class should provide the logic for generating text responses based on input prompts and optional attachments.
- Implemented types
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
history
↔ Iterable<
ChatMessage> -
Returns an iterable of ChatMessage objects representing the chat
history.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
inherited
-
generateStream(
String prompt, {Iterable< Attachment> attachments}) → Stream<String> - Generates a stream of text based on the given prompt and attachments. This method does not interact with a chat or build on any chat history.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
sendMessageStream(
String prompt, {Iterable< Attachment> attachments}) → Stream<String> - Generates a stream of text based on the given prompt and attachments. Interacts with a chat and builds on the history of the chat associated with the provider.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited